@@ -2,7 +2,7 @@ package Catmandu::Importer::CSV;
 
 use Catmandu::Sane;
 
-our $VERSION = '1.2023';
+our $VERSION = '1.2025';
 
 use Text::CSV;
 use List::Util qw(reduce);
@@ -11,7 +11,7 @@ use namespace::clean;
 
 with 'Catmandu::Importer';
 
-has csv      => (is => 'ro', lazy => 1, builder => '_build_csv');
+has csv => (is => 'ro', lazy => 1, builder => '_build_csv');
 has sep_char => (
     is      => 'ro',
     default => sub {','},
@@ -26,7 +26,7 @@ has escape_char         => (is => 'ro', default => sub {'"'});
 has allow_loose_quotes  => (is => 'ro', default => sub {0});
 has allow_loose_escapes => (is => 'ro', default => sub {0});
 has header              => (is => 'ro', default => sub {1});
-has fields              => (
+has fields => (
     is     => 'rwp',
     coerce => sub {
         my $fields = $_[0];
@@ -42,7 +42,7 @@ sub _build_csv {
         {
             binary      => 1,
             sep_char    => $self->sep_char,
-            quote_char  => $self->quote_char ? $self->quote_char : undef,
+            quote_char  => $self->quote_char  ? $self->quote_char  : undef,
             escape_char => $self->escape_char ? $self->escape_char : undef,
             allow_loose_quotes  => $self->allow_loose_quotes,
             allow_loose_escapes => $self->allow_loose_escapes,
@@ -58,11 +58,12 @@ sub generator {
         state $csv  = do {
             if ($self->header) {
                 if ($self->fields) {
-                    $self->csv->getline($fh);
+                    $self->csv->header($fh, { 'sep_set' => [$self->sep_char] });
                     $line++;
                 }
                 else {
-                    $self->_set_fields($self->csv->getline($fh));
+                    my @hdr = $self->csv->header($fh, { 'munge_column_names' => 'none', 'sep_set' => [$self->sep_char] });
+                    $self->_set_fields(\@hdr);
                     $line++;
                 }
             }
@@ -82,8 +83,7 @@ sub generator {
             return reduce {
                 $a->{$b} = $row->[$b] if length $row->[$b];
                 $a;
-            }
-            +{}, @$fields;
+            } +{}, @$fields;
         }
 
         my $rec = $csv->getline_hr($fh);
