@@ -2,7 +2,7 @@ package Catmandu::Path::simple;
 
 use Catmandu::Sane;
 
-our $VERSION = '1.2023';
+our $VERSION = '1.2025';
 
 use Catmandu::Util
     qw(is_hash_ref is_array_ref is_value is_natural is_code_ref trim);
@@ -398,11 +398,13 @@ sub _emit_delete_key {
         $perl .= "} elsif (is_array_ref(${var}) && \@{${var}} > ${key}) {";
         $perl .= "splice(\@{${var}}, ${key}, 1)";
     }
-    elsif (defined($key) && ($key eq '$first' || $key eq '$last' || $key eq '*')) {
+    elsif (defined($key)
+        && ($key eq '$first' || $key eq '$last' || $key eq '*'))
+    {
         $perl .= "if (is_array_ref(${var}) && \@{${var}}) {";
-        $perl .= "splice(\@{${var}}, 0, 1)" if $key eq '$first';
+        $perl .= "splice(\@{${var}}, 0, 1)"              if $key eq '$first';
         $perl .= "splice(\@{${var}}, \@{${var}} - 1, 1)" if $key eq '$last';
-        $perl .= "splice(\@{${var}}, 0, \@{${var}})" if $key eq '*';
+        $perl .= "splice(\@{${var}}, 0, \@{${var}})"     if $key eq '*';
     }
     else {
         $perl .= "if (is_hash_ref(${var})) {";
@@ -416,7 +418,7 @@ sub _emit_delete_key {
 
 sub unquote {
     my ($self, $str) = @_;
-    if (! defined $str) {
+    if (!defined $str) {
         return $str;
     }
     elsif ($str =~ /^['](.*)[']$/) {
